==> universal_html-1.0.6.tar.gz: lib/src/html/xml.dart <==
/*
Some source code in this file was adopted from 'dart:html' in Dart SDK. See:
  https://github.com/dart-lang/sdk/tree/master/tools/dom

The source code adopted from 'dart:html' had the following license:

  Copyright 2012, the Dart project authors. All rights reserved.
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are
  met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
      copyright notice, this list of conditions and the following
      disclaimer in the documentation and/or other materials provided
      with the distribution.
    * Neither the name of Google Inc. nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

part of universal_html;

class XmlDocument extends Document {
  /// IMPORTANT: Not part of 'dart:html' API.
  @visibleForTesting
  XmlDocument.internal(HtmlDriver htmlDriver,
      {String contentType = "application/xml"})
      : assert(contentType != null),
        super._(htmlDriver, contentType);

  List<StyleSheet> get styleSheets {
    // TODO: Fix style sheet search
    final nodes = getElementsByTagName("style");
    final result = <StyleSheet>[];
    for (var node in nodes) {
      if (node is StyleElement) {
        final sheet = node.sheet;
        if (sheet != null) {
          result.add(node.sheet);
        }
      }
    }
    return result;
  }

  @override
  Node internalCloneWithOwnerDocument(Document ownerDocument, bool deep) {
    final clone = XmlDocument.internal(_htmlDriver, contentType: contentType);
    if (deep != false) {
      Node._cloneChildrenFrom(clone, clone, this);
    }
    return clone;
  }
}

==> universal_html-1.0.7.tar.gz: lib/src/html/xml.dart <==
/*
Some source code in this file was adopted from 'dart:html' in Dart SDK. See:
  https://github.com/dart-lang/sdk/tree/master/tools/dom

The source code adopted from 'dart:html' had the following license:

  Copyright 2012, the Dart project authors. All rights reserved.
  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are
  met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above
      copyright notice, this list of conditions and the following
      disclaimer in the documentation and/or other materials provided
      with the distribution.
    * Neither the name of Google Inc. nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

part of universal_html;

class XmlDocument extends Document {
  /// IMPORTANT: Not part of 'dart:html' API.
  @visibleForTesting
  XmlDocument.internal(HtmlDriver htmlDriver, {@required String contentType})
      : assert(contentType != null),
        super._(htmlDriver, contentType);

  List<StyleSheet> get styleSheets {
    // TODO: Fix style sheet search
    final nodes = getElementsByTagName("style");
    final result = <StyleSheet>[];
    for (var node in nodes) {
      if (node is StyleElement) {
        final sheet = node.sheet;
        if (sheet != null) {
          result.add(node.sheet);
        }
      }
    }
    return result;
  }

  @override
  Node internalCloneWithOwnerDocument(Document ownerDocument, bool deep) {
    final clone = XmlDocument.internal(_htmlDriver, contentType: contentType);
    if (deep != false) {
      Node._cloneChildrenFrom(clone, clone, this);
    }
    return clone;
  }
}
